@@ -224,7 +224,9 @@ func (s *Resources) CreateAssetGroupTagSelector(response http.ResponseWriter, re
 			description = *createSelectorRequest.Description
 		}
 
-		if selector, err := s.DB.CreateAssetGroupTagSelector(request.Context(), assetTagId, actor, createSelectorRequest.Name, description, false, true, autoCertify, createSelectorRequest.Seeds); err != nil {
+		if selector, err := s.DB.CreateAssetGroupTagSelector(request.Context(), assetTagId, actor, createSelectorRequest.Name, description, false, true, autoCertify, createSelectorRequest.Seeds); errors.Is(err, database.ErrDuplicateAGTagSelectorName) {
+			api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusConflict, api.ErrorResponseAssetGroupTagSelectorDuplicateName, request), response)
+		} else if err != nil {
 			api.HandleDatabaseError(request, response, err)
 		} else if config, err := appcfg.GetScheduledAnalysisParameter(request.Context(), s.DB); err != nil {
 			api.HandleDatabaseError(request, response, err)
@@ -931,7 +933,7 @@ func (s *Resources) GetAssetGroupMembersBySelector(response http.ResponseWriter,
 		api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusNotFound, api.ErrorResponseDetailsIDMalformed, request), response)
 	} else if selector, err := s.DB.GetAssetGroupTagSelectorBySelectorId(request.Context(), selectorId); err != nil {
 		api.HandleDatabaseError(request, response, err)
-	} else if sort, err := api.ParseSortParameters(AssetGroupMember{}, queryParams); err != nil {
+	} else if sort, err := api.ParseGraphSortParameters(AssetGroupMember{}, queryParams); err != nil {
 		api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusBadRequest, api.ErrorResponseDetailsNotSortable, request), response)
 	} else if skip, err := ParseSkipQueryParameter(queryParams, 0); err != nil {
 		api.WriteErrorResponse(request.Context(), ErrBadQueryParameter(request, model.PaginationQueryParameterSkip, err), response)
@@ -943,24 +945,7 @@ func (s *Resources) GetAssetGroupMembersBySelector(response http.ResponseWriter,
 		api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusConflict, "selector is disabled", request), response)
 	} else {
 		if len(sort) == 0 {
-			sort = model.Sort{{Column: "node_id", Direction: model.AscendingSortDirection}}
-		} else {
-			// sort items must be translated to the respective columns on the selector nodes table
-			for i, sortItem := range sort {
-				switch sortItem.Column {
-				case "id":
-					sort[i].Column = "node_id"
-				case "objectid":
-					sort[i].Column = "node_object_id"
-				case "name":
-					sort[i].Column = "node_name"
-				}
-			}
-		}
-
-		if len(environmentIds) > 0 {
-			filter.SQLString = "AND node_environment_id IN ?"
-			filter.Params = append(filter.Params, environmentIds)
+			sort = query.SortItems{{SortCriteria: query.NodeID(), Direction: query.SortDirectionAscending}}
 		}
 
 		if assetGroupTag.RequireCertify.ValueOrZero() {
@@ -968,22 +953,45 @@ func (s *Resources) GetAssetGroupMembersBySelector(response http.ResponseWriter,
 			filter.Params = append(filter.Params, model.AssetGroupCertificationRevoked)
 		}
 
-		if selectorNodes, count, err := s.DB.GetSelectorNodesBySelectorIdsFilteredAndPaginated(request.Context(), filter, sort, skip, limit, selectorId); err != nil {
+		// In order to get an accurate count, this needs to grab the entire selector node record space
+		if selectorNodes, _, err := s.DB.GetSelectorNodesBySelectorIdsFilteredAndPaginated(request.Context(), filter, model.Sort{}, 0, 0, selectorId); err != nil {
 			api.HandleDatabaseError(request, response, err)
 		} else {
+			var (
+				nodeIds        = make([]graph.ID, 0, len(selectorNodes))
+				sourceByNodeId = make(map[graph.ID]model.AssetGroupSelectorNodeSource, len(selectorNodes))
+			)
+
 			for _, node := range selectorNodes {
-				members = append(members, AssetGroupMember{
-					NodeId:          node.NodeId,
-					ObjectID:        node.NodeObjectId,
-					EnvironmentID:   node.NodeEnvironmentId,
-					PrimaryKind:     node.NodePrimaryKind,
-					Name:            node.NodeName,
-					Source:          node.Source,
-					AssetGroupTagId: assetGroupTag.ID,
-				})
+				nodeIds = append(nodeIds, node.NodeId)
+				sourceByNodeId[node.NodeId] = node.Source
 			}
 
-			api.WriteResponseWrapperWithPagination(request.Context(), GetAssetGroupMembersResponse{Members: members}, limit, skip, count, http.StatusOK, response)
+			filters := []graph.Criteria{
+				query.KindIn(query.Node(), assetGroupTag.ToKind()),
+				query.InIDs(query.NodeID(), nodeIds...),
+			}
+			if len(environmentIds) > 0 {
+				filters = append(filters, query.Or(
+					query.In(query.NodeProperty(ad.DomainSID.String()), environmentIds),
+					query.In(query.NodeProperty(azure.TenantID.String()), environmentIds),
+				))
+			}
+
+			if nodes, err := s.GraphQuery.GetFilteredAndSortedNodesPaginated(sort, query.And(filters...), skip, limit); err != nil {
+				api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusInternalServerError, fmt.Sprintf("Error getting members: %v", err), request), response)
+			} else if count, err := s.GraphQuery.CountFilteredNodes(request.Context(), query.And(filters...)); err != nil {
+				api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusInternalServerError, fmt.Sprintf("Error getting member count: %v", err), request), response)
+			} else {
+				for _, node := range nodes {
+					member := nodeToAssetGroupMember(node, false)
+					member.AssetGroupTagId = assetGroupTag.ID
+					member.Source = sourceByNodeId[node.ID]
+					members = append(members, member)
+				}
+
+				api.WriteResponseWrapperWithPagination(request.Context(), GetAssetGroupMembersResponse{Members: members}, limit, skip, int(count), http.StatusOK, response)
+			}
 		}
 	}
 }
