@@ -14,4 +14,4 @@
 --
 -- SPDX-License-Identifier: Apache-2.0
 
-DROP TABLE baz_test;
+ALTER TABLE foo_test RENAME TO baz_test;
