@@ -17,13 +17,16 @@
 package golang
 
 import (
+	"bufio"
 	"context"
 	"encoding/json"
 	"errors"
 	"fmt"
+	"log/slog"
 	"os"
 	"path/filepath"
 	"regexp"
+	"strings"
 
 	"github.com/gofrs/uuid"
 	"github.com/specterops/bloodhound/packages/go/slicesext"
@@ -52,7 +55,7 @@ var (
 )
 
 // TestWorkspace runs all Go tests for a given workspace. Setting integration to true will run integration tests, otherwise we only run unit tests
-func TestWorkspace(cwd string, modPath string, profileDir string, env environment.Environment, integration bool, tags string) error {
+func TestWorkspace(cwd string, modPath string, profileDir string, env environment.Environment, integration bool, tags string, goReporting bool) error {
 	var (
 		manifest = make(map[string]string, len(modPath))
 		command  = "go"
@@ -69,6 +72,10 @@ func TestWorkspace(cwd string, modPath string, profileDir string, env environmen
 		args = append(args, []string{"-tags", tags}...)
 	}
 
+	if goReporting {
+		args = append(args, []string{"-json"}...)
+	}
+
 	modName, err := getModuleName(modPath)
 	if err != nil {
 		return err
@@ -89,10 +96,25 @@ func TestWorkspace(cwd string, modPath string, profileDir string, env environmen
 		Path:    modPath,
 		Env:     env.Slice(),
 	}
-	if _, err := cmdrunner.Run(context.TODO(), executionPlan); err != nil {
+
+	output, err := cmdrunner.Run(context.TODO(), executionPlan)
+	if err != nil {
 		return fmt.Errorf("go test at %v: %w", modPath, err)
 	}
 
+	if goReporting {
+		file, err := os.Create(filepath.Join(cwd, "go-test-results.json"))
+		if err != nil {
+			return fmt.Errorf("error creating a file: %w", err)
+		}
+
+		defer file.Close()
+
+		if _, err := file.Write(output.StandardOutput.Bytes()); err != nil {
+			return fmt.Errorf("error writing test results: %w", err)
+		}
+	}
+
 	if manifestFile, err := os.Create(filepath.Join(profileDir, CoverageManifest)); err != nil {
 		return fmt.Errorf("create manifest file: %w", err)
 	} else if marshaledManifest, err := json.Marshal(manifest); err != nil {
@@ -112,6 +134,12 @@ var (
 	combinedCoverageRegex = regexp.MustCompile(`total:\s+\(.*?\)\s+(\d+(?:.\d+)?%)`)
 )
 
+type Package struct {
+	Path       string
+	Function   string
+	Percentage string
+}
+
 // GetCombinedCoverage takes a coverage file and returns a string representation of percentage of statements covered
 func GetCombinedCoverage(coverFile string, env environment.Environment) (string, error) {
 	var (
@@ -127,7 +155,52 @@ func GetCombinedCoverage(coverFile string, env environment.Environment) (string,
 	if result, err := cmdrunner.Run(context.TODO(), executionPlan); err != nil {
 		return "", fmt.Errorf("combined coverage: %w", err)
 	} else {
+		var Pkgs []Package
 		matches := combinedCoverageRegex.FindStringSubmatch(result.StandardOutput.String())
+		fileReader := bufio.NewReader(result.StandardOutput)
+		fileScanner := bufio.NewScanner(fileReader)
+
+		for fileScanner.Scan() {
+			// Skip the total line - it's already captured by the regex
+			if strings.HasPrefix(fileScanner.Text(), "total:") {
+				continue
+			}
+
+			list := strings.Fields(fileScanner.Text())
+			if len(list) < 3 {
+				continue
+			}
+			Pkg := Package{
+				Path:       list[0],
+				Function:   list[1],
+				Percentage: list[2],
+			}
+			Pkgs = append(Pkgs, Pkg)
+		}
+
+		cwd, err := os.Getwd()
+		if err != nil {
+			return "", fmt.Errorf("get working directory: %w", err)
+		}
+
+		coverageDir := filepath.Join(cwd, "tmp", "coverage")
+		file, err := os.Create(filepath.Join(coverageDir, "code_coverage.json"))
+		if err != nil {
+			return "", fmt.Errorf("error creating a file: %w", err)
+		}
+
+		defer file.Close()
+
+		content, err := json.Marshal(Pkgs)
+		if err != nil {
+			return "", fmt.Errorf("marshal coverage data: %w", err)
+		}
+		// Capture Coverage for Golang Packages
+		_, err = file.Write(content)
+		if err != nil {
+			return "", fmt.Errorf("error writing content error: %w", err)
+		}
+		slog.Info("Code coverage file created successfully")
 
 		// This regex has only one capture group, so we expect the percentage to be in the capture group portion of the matches
 		// There should be two matches since the first match result is the full string that was matched, and the second is the result of our capture group
