@@ -20,7 +20,7 @@ import { FC } from 'react';
 const References: FC = () => {
     return (
         <Box sx={{ overflowX: 'auto' }}>
-            <Link target='_blank' rel='noopener' href='https://adsecurity.org/?p=3700'>
+            <Link target='_blank' rel='noopener noreferrer' href='https://adsecurity.org/?p=3700'>
                 Beyond Domain Admins
             </Link>
             <br />
