@@ -18,5 +18,7 @@ import MainNav from './MainNav';
 import SubNav from './SubNav';
 import { MainNavData } from './types';
 
+export * from './AppLink';
+export * from './AppNavigate';
 export * from './utils';
 export { MainNav, SubNav, type MainNavData };
