@@ -33,3 +33,11 @@ export const useBloodHoundUsers = () => {
         enabled: hasPermission,
     });
 };
+
+export const useGetUser = (userId: string) => {
+    return useQuery(
+        ['getUser', userId],
+        ({ signal }) => apiClient.getUser(userId, { signal }).then((res) => res.data.data),
+        { cacheTime: 0 }
+    );
+};
