@@ -89,7 +89,7 @@ export const Cypher: FC<{
         <Card className={cn({ 'min-h-[36rem] max-h-[36rem]': !preview })}>
             <CardHeader>
                 <div className='flex justify-between items-center px-6 pt-3'>
-                    <CardTitle>{preview ? 'Cypher Preview' : 'Cypher Search'}</CardTitle>
+                    <CardTitle>{preview ? 'Cypher Preview' : 'Cypher Rule'}</CardTitle>
                     <div className='flex gap-6'>
                         <Button variant={'text'} className='p-0 text-sm' asChild>
                             <a href={exploreUrl} target='_blank' rel='noreferrer'>
@@ -115,9 +115,9 @@ export const Cypher: FC<{
                 {!preview && (
                     <p className='italic px-6 mt-2 text-sm'>
                         Note: The sample results from running this cypher search may include additional entities that
-                        are not directly associated with the cypher query due to default selector expansion. In
-                        contrast, 'View in Explore' will show only the entities that are directly associated with the
-                        cypher query.
+                        are not directly associated with the cypher query due to default Rule expansion. In contrast,
+                        'View in Explore' will show only the entities that are directly associated with the cypher
+                        query.
                     </p>
                 )}
             </CardHeader>
@@ -148,7 +148,7 @@ export const Cypher: FC<{
                 {showLabelWarning && (
                     <p className='text-error text-sm p-2'>
                         Privilege Zone labels should only be used in cypher within the Explore page. Utilizing Privilege
-                        Zone labels in a cypher based Selector seed may result in incomplete data.
+                        Zone labels in a cypher based Rule seed may result in incomplete data.
                     </p>
                 )}
             </CardContent>
