@@ -14,9 +14,9 @@
 //
 // SPDX-License-Identifier: Apache-2.0
 
-import Details, { getSavePath } from './Details';
+import Details from './Details';
 import EntitySelectorsInformation from './EntitySelectorsInformation';
 import { SelectedDetails } from './SelectedDetails';
 
-export { EntitySelectorsInformation, SelectedDetails, getSavePath };
+export { EntitySelectorsInformation, SelectedDetails };
 export default Details;
